iex
===
A Python module to retrieve stock market data from `The Investors Exchange (IEX) <https://iextrading.com/>`__
Developer Platform.

Documentation
-------------
Read the IEX Developer Platform documentation `here <https://iextrading.com/developer/docs/>`__.

Installation
------------
From PyPI with pip:

``$ pip3 install iex``

From GitHub:

.. code:: bash

     $ git clone https://github.com/udrea/iex.git
     $ cd iex
     $ python3 setup.py install

Module stability
----------------
This Python module is currently under heavy development and nowhere near any
stable version. It is subject to regular breaking changes.

License
-------
Copyright 2018 Iulian Udrea <iulian.udrea14@alumni.imperial.ac.uk>

See LICENSE.
